Changelog history — A Python Environment for (phylogenetic) Tree Exploration

### Navigation

- index
- modules |
- next |
- previous |
- ETE documentation »

# Changelog history

- What’s new in ETE 2.1

#### Previous topic

Download and Install

#### Next topic

What’s new in ETE 2.1

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- ETE documentation »

© Copyright 2011, Jaime Huerta-Cepas & Toni Gabaldón. Last updated on Jun 29, 2012. Created using Sphinx 1.1.2.